/***                */
/**  USB ECHO TOP  **/
/*                ***/
module clock_top( CLK, PSW0, PSW1, PSW3, RXF_N, TXE_N, RD_N, WR, USB_DATA, SG, SA );

input       CLK, PSW0, PSW1, PSW3;
input       RXF_N, TXE_N;
output      RD_N, WR;
output [6:0] SG;
output [3:0] SA;
inout [7:0] USB_DATA;

wire        TgBUSY, TgREADY;
wire        UsbBUSY, UsbREADY;
wire        TG_RD, TG_WR;

wire        RST;
wire  [7:0] DATA_IN;
wire  [7:0] DATA_OUT; 
wire        SEC;
wire        SW0, SW1;
wire  [3:0] MIN_L, MIN_H, HUR_L, HUR_H;
wire        IN_SW0, IN_SW1;
wire        REG_SW0, REG_SW1;

assign RST = ~PSW3;
assign SW0 = ~PSW0;
assign SW1 = ~PSW1;

REM_CHAT U0 ( .CLK(CLK), .RST(RST), .DIN(SW0), .DOUT(IN_SW0) );
REM_CHAT U1 ( .CLK(CLK), .RST(RST), .DIN(SW1), .DOUT(IN_SW1) );

DIFF_PLS U2 ( .CLK(CLK), .RST(RST), .DIN(IN_SW0), .DOUT(REG_SW0) );
DIFF_PLS U3 ( .CLK(CLK), .RST(RST), .DIN(IN_SW1), .DOUT(REG_SW1) );

CLOCK U4( .CLK(CLK), 
          .CE(SEC), 
			 .RST(RST),
		    .SW1(REG_SW0),
		    .SW2(REG_SW1), 
			 .O_MIN_H(MIN_H), 
			 .O_MIN_L(MIN_L), 
			 .O_HUR_H(HUR_H),
		    .O_HUR_L(HUR_L) );

CLK_DIV U5( .CLK(CLK), .RST(RST), .CEO(SEC) );

SEG_CTL U6( .CLK( CLK ), .RST( RST ), 
            .DATA_A( MIN_L ), 
				.DATA_B( MIN_H ), 
				.DATA_C( HUR_L ), 
				.DATA_D( HUR_H ), 
				.SG( SG ), .SA( SA ) );

USB_ARBITER U7 
		  ( .CLK(CLK),
			 .RST(RST),

			 .RXF_N(RXF_N), // IN
			 .TXE_N(TXE_N), // IN
			 .RD_N(RD_N),   // OUT
			 .WR(WR),       // OUT

			 .BUS_BUSY(UsbBUSY),   // OUT
			 .TG_READY(TgREADY),  // IN

			 .USB_DATA(USB_DATA), 

			 .TG_DO(DATA_IN),
			 .TG_DI(DATA_OUT), 
			 .TG_RD(TG_RD),
			 .TG_WR(TG_WR) );

assign UsbREADY = ~UsbBUSY;
assign TgREADY  = ~TgBUSY;

REPLY U8 
	( .CLK(CLK), 
	  .RST(RST), 
	  .BUSY(TgBUSY),
     .READY(UsbREADY), 
	  .HUR( {HUR_H,HUR_L} ), 
	  .MIN( {MIN_H,MIN_L} ),
     .RE(TG_RD),
	  .DIN(DATA_IN),
     .WE(TG_WR),
	  .DOUT(DATA_OUT) );


endmodule
